<?php
/**
 * Joyce functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Joyce
 */


if ( ! function_exists( 'joyce_after_theme_support' ) ) :

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */

	function joyce_after_theme_support() {

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// Custom background color.
		add_theme_support(
			'custom-background',
			array(
				'default-color' => 'fafafa',
			)
		);

		// This variable is intended to be overruled from themes.
		// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
		// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
		$GLOBALS['content_width'] = apply_filters( 'joyce_content_width', 1140 );
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		add_theme_support(
			'custom-logo',
			array(
				'height'      => 270,
				'width'       => 90,
				'flex-height' => true,
				'flex-width'  => true,
			)
		);

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'script',
				'style',
			)
		);

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Joyce, use a find and replace
		 * to change 'joyce' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'joyce', get_template_directory() . '/languages' );

		// Add support for full and wide align images.
        add_theme_support( 'align-wide' );
        add_theme_support( 'responsive-embeds' );
        add_theme_support( 'wp-block-styles' );

	}

endif;

add_action( 'after_setup_theme', 'joyce_after_theme_support' );

/**
 * Register and Enqueue Styles.
 */
function joyce_register_styles() {

	$theme_version = wp_get_theme()->get( 'Version' );
	$fonts_url = joyce_fonts_url();
    if( $fonts_url ){
    	
    	require_once get_theme_file_path( 'assets/lib/custom/css/wptt-webfont-loader.php' );
        wp_enqueue_style(
			'joyce-google-fonts',
			wptt_get_webfont_url( $fonts_url ),
			array(),
			$theme_version
		);
    }
    
    wp_enqueue_style( 'swiper', get_template_directory_uri() . '/assets/lib/swiper/css/swiper-bundle.min.css');
    wp_enqueue_style( 'aos', get_template_directory_uri() . '/assets/lib/aos/css/aos.min.css');
	wp_enqueue_style( 'joyce-style', get_stylesheet_uri(), array(), $theme_version );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}	

	wp_enqueue_script( 'imagesloaded' );
    wp_enqueue_script( 'masonry' );
	wp_enqueue_script( 'swiper', get_template_directory_uri() . '/assets/lib/swiper/js/swiper-bundle.min.js', array('jquery'), '', 1);
	wp_enqueue_script( 'aos', get_template_directory_uri() . '/assets/lib/aos/js/aos.min.js', array('jquery'), '', 1);
	wp_enqueue_script( 'joyce-pagination', get_template_directory_uri() . '/assets/lib/custom/js/pagination.js', array('jquery'), '', 1 );
	wp_enqueue_script( 'joyce-custom', get_template_directory_uri() . '/assets/lib/custom/js/custom.js', array('jquery'), '', 1);

    // Global Query
    if( is_front_page() ){

    	$posts_per_page = absint( get_option('posts_per_page') );
        $c_paged = ( get_query_var( 'page' ) ) ? absint( get_query_var( 'page' ) ) : 1;
        $posts_args = array(
            'posts_per_page'        => $posts_per_page,
            'paged'                 => $c_paged,
        );
        $posts_qry = new WP_Query( $posts_args );
        $max = $posts_qry->max_num_pages;

    }else{
        global $wp_query;
        $max = $wp_query->max_num_pages;
        $c_paged = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
    }

    $joyce_default = joyce_get_default_theme_options();
    $joyce_pagination_layout = get_theme_mod( 'joyce_pagination_layout',$joyce_default['joyce_pagination_layout'] );
    $ajax_nonce = wp_create_nonce('joyce_ajax_nonce');
    // Pagination Data
    wp_localize_script( 
	    'joyce-pagination', 
	    'joyce_pagination',
	    array(
	        'paged'  => absint( $c_paged ),
	        'maxpage'   => absint( $max ),
	        'nextLink'   => next_posts( $max, false ),
	        'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
	        'loadmore'   => esc_html__( 'Load More Posts', 'joyce' ),
	        'nomore'     => esc_html__( 'No More Posts', 'joyce' ),
	        'loading'    => esc_html__( 'Loading...', 'joyce' ),
	        'pagination_layout'   => esc_html( $joyce_pagination_layout ),
	        'ajax_nonce' => $ajax_nonce,
	     )
	);

    global $post;
    $single_post = 0;
    $joyce_ed_post_reaction = '';
    if( isset( $post->ID ) && isset( $post->post_type ) && $post->post_type == 'post' ){

    	$joyce_ed_post_reaction = esc_html( get_post_meta( $post->ID, 'joyce_ed_post_reaction', true ) );
    	$single_post = 1;

    }

    $joyce_color_scheme = get_theme_mod( 'joyce_color_scheme',$joyce_default['joyce_color_scheme'] );
	wp_localize_script(
	    'joyce-custom', 
	    'joyce_custom',
	    array(
	    	'single_post'	=> absint( $single_post ),
	        'joyce_ed_post_reaction'  		=> esc_html( $joyce_ed_post_reaction ),
	        'next_svg'   => joyce_the_theme_svg('chevron-right',true),
            'prev_svg' => joyce_the_theme_svg('chevron-left',true),
            'close' => joyce_the_theme_svg('close',true),
            'plus' => joyce_the_theme_svg('plus',true),
            'joyce_color_scheme' => $joyce_color_scheme,
	     )
	);

}

add_action( 'wp_enqueue_scripts', 'joyce_register_styles' );

/**
 * Admin enqueue script
 */
function joyce_admin_scripts($hook){

	wp_enqueue_media();
    wp_enqueue_style('joyce-admin', get_template_directory_uri() . '/assets/lib/custom/css/admin.css');
    wp_enqueue_script('joyce-admin', get_template_directory_uri() . '/assets/lib/custom/js/admin.js', array('jquery'), '', 1);
    
    $ajax_nonce = wp_create_nonce('joyce_ajax_nonce');
				
	wp_localize_script( 
        'joyce-admin', 
        'joyce_admin',
        array(
            'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
            'ajax_nonce' => $ajax_nonce,
            'upload_image'   =>  esc_html__('Choose Image','joyce'),
            'use_image'   =>  esc_html__('Select','joyce'),
            'active' => esc_html__('Active','joyce'),
	        'deactivate' => esc_html__('Deactivate','joyce'),
         )
    );

}

add_action('admin_enqueue_scripts', 'joyce_admin_scripts');

if( !function_exists( 'joyce_js_no_js_class' ) ) :

	// js no-js class toggle
	function joyce_js_no_js_class() { ?>

		<script>document.documentElement.className = document.documentElement.className.replace( 'no-js', 'js' );</script>
	
	<?php
	}
	
endif;

add_action( 'wp_head', 'joyce_js_no_js_class' );

/**
 * Register navigation menus uses wp_nav_menu in five places.
 */
function joyce_menus() {

	$locations = array(
		'joyce-primary-menu'  => esc_html__( 'Primary Menu', 'joyce' ),
		'joyce-social-menu'  => esc_html__( 'Social Menu', 'joyce' ),
	);

	register_nav_menus( $locations );
}

add_action( 'init', 'joyce_menus' );

require get_template_directory() . '/inc/custom-header.php';
require get_template_directory() . '/inc/mega-menu/megamenu-custom-fields.php';
require get_template_directory() . '/inc/mega-menu/walkernav.php';
require get_template_directory() . '/assets/lib/tgmpa/recommended-plugins.php';
require get_template_directory() . '/classes/class-svg-icons.php';
require get_template_directory() . '/classes/class-walker-menu.php';
require get_template_directory() . '/inc/customizer/customizer.php';
require get_template_directory() . '/inc/custom-functions.php';
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/classes/body-classes.php';
require get_template_directory() . '/inc/widgets/widgets.php';
require get_template_directory() . '/inc/metabox.php';
require get_template_directory() . '/inc/term-meta.php';
require get_template_directory() . '/inc/pagination.php';
require get_template_directory() . '/assets/lib/breadcrumbs/breadcrumbs.php';
require get_template_directory() . '/assets/lib/custom/css/style.php';
require get_template_directory() . '/woocommerce/woocommerce-functions.php';
require get_template_directory() . '/classes/admin-notice.php';
require get_template_directory() . '/classes/plugin-classes.php';
require get_template_directory() . '/classes/about.php';

if( class_exists('Demo_Import_Kit_Class') ):

	add_filter('themeinwp_enable_demo_import_compatiblity','joyce_demo_import_filter_apply');

	if( !function_exists('joyce_demo_import_filter_apply') ):

		function joyce_demo_import_filter_apply(){

			return true;

		}

	endif;

endif;