<?php
/**
 * Header file for the Joyce WordPress theme.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Joyce
 * @since 1.0.0
 */
?><!DOCTYPE html>
<html class="no-js" <?php language_attributes(); ?>>

<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no" />
    <link rel="profile" href="https://gmpg.org/xfn/11">
    <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php
if( function_exists('wp_body_open') ){
    wp_body_open();
}
$joyce_default = joyce_get_default_theme_options();
$ed_preloader = get_theme_mod( 'ed_preloader', $joyce_default['ed_preloader'] );
$ed_cursor_option = get_theme_mod( 'ed_cursor_option', $joyce_default['ed_cursor_option'] ); ?>

<?php if( $ed_preloader ){ ?>

    <div class="preloader hide-no-js">
        <div class="preloader-wrapper">
            <span class="dot"></span>
            <div class="dots">
                <span></span>
                <span></span>
                <span></span>
            </div>
        </div>
    </div>

<?php } ?>
<?php if ($ed_cursor_option) { ?>
    <div class="theme-custom-cursor theme-cursor-primary"></div>
    <div class="theme-custom-cursor theme-cursor-secondary"></div>
<?php }?>


<div id="joyce-page" class="joyce-hfeed joyce-site">
<a class="skip-link screen-reader-text" href="#site-content"><?php esc_html_e('Skip to the content', 'joyce'); ?></a>

<?php
$joyce_header_layout = get_theme_mod( 'joyce_header_layout', $joyce_default['joyce_header_layout'] );
get_template_part( 'template-parts/header/header', $joyce_header_layout );
?>

<div id="content" class="site-content">

    <?php 
if (is_single()) {
    $joyce_default = joyce_get_default_theme_options();

    $twp_single_image_alignment = get_post_meta(get_the_ID(), 'joyce_single_image_layout', true);
    if (empty($twp_single_image_alignment)) {
        $twp_single_image_alignment = get_theme_mod('twp_single_image_alignment', $joyce_default['twp_single_image_alignment']);
    }


    if ($twp_single_image_alignment == 'layout-2') { ?>
    <div class="single-featured-banner">
        <?php

        $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
        $featured_image = isset($featured_image[0]) ? $featured_image[0] : '';
        ?>
        <div class="data-bg" data-background="<?php echo esc_url($featured_image); ?>">
            <div class="wrapper">
                <div class="column-row">
                    <div class="column column-11">
                        <div class="featured-banner-content">
                            <?php joyce_breadcrumb(); ?>
                            <header class="entry-header entry-header-1">
                                <h1 class="entry-title entry-title-large">
                                    <?php the_title(); ?>
                                </h1>
                            </header>
                            <?php if (!is_page()) {  ?>
                                <div class="entry-meta">
                                    <?php global $post;
                                    $author_id = $post->post_author;?>
                                    <div class="entry-meta-item entry-meta-author">
                                        <div class="entry-meta-wrapper">
                                            <span class="entry-meta-icon author-icon"> 
                                            <?php joyce_the_theme_svg('user'); ?>
                                            </span>
                                            <?php $byline = '<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta('ID') ) ) . '">' . esc_html( get_the_author_meta( 'nicename', $author_id )) . '</a></span>'; ?>
                                            <span class="byline"> <?php echo wp_kses_post($byline); ?></span> 
                                        </div>
                                    </div>
                                    <?php
                                    joyce_posted_on();
                                    joyce_entry_footer( $cats = true, $tags = false, $edits = false );
                                    ?>

                                </div>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php }
}
