<?php
/**
 * Custom Functions.
 *
 * @package Joyce
 */

if( !function_exists( 'joyce_social_menu_icon' ) ) :

    function joyce_social_menu_icon( $item_output, $item, $depth, $args ) {

        // Add Icon
        if ( isset( $args->theme_location ) && 'joyce-social-menu' === $args->theme_location ) {

            $svg = Joyce_SVG_Icons::get_theme_svg_name( $item->url );

            if ( empty( $svg ) ) {
                $svg = joyce_the_theme_svg( 'link',$return = true );
            }

            $item_output = str_replace( $args->link_after, '</span>' . $svg, $item_output );
        }

        return $item_output;
    }

endif;

add_filter( 'walker_nav_menu_start_el', 'joyce_social_menu_icon', 10, 4 );

if ( ! function_exists( 'joyce_sub_menu_toggle_button' ) ) :

    function joyce_sub_menu_toggle_button( $args, $item, $depth ) {

        // Add sub menu toggles to the main menu with toggles
        if ( $args->theme_location == 'joyce-primary-menu' && isset( $args->show_toggles ) ) {
            
            // Wrap the menu item link contents in a div, used for positioning
            $args->before = '<div class="submenu-wrapper">';
            $args->after  = '';

            // Add a toggle to items with children
            if ( in_array( 'menu-item-has-children', $item->classes ) ) {

                $toggle_target_string = '.menu-item.menu-item-' . $item->ID . ' > .sub-menu';

                // Add the sub menu toggle
                $args->after .= '<button type="button" class="theme-aria-button submenu-toggle" data-toggle-target="' . $toggle_target_string . '" data-toggle-type="slidetoggle" data-toggle-duration="250" aria-expanded="false"><span class="btn__content" tabindex="-1"><span class="screen-reader-text">' . esc_html__( 'Show sub menu', 'joyce' ) . '</span>' . joyce_get_theme_svg( 'chevron-down' ) . '</span></button>';

            }

            // Close the wrapper
            $args->after .= '</div><!-- .submenu-wrapper -->';
            // Add sub menu icons to the main menu without toggles (the fallback menu)

        }elseif( $args->theme_location == 'joyce-primary-menu' ) {

            if ( in_array( 'menu-item-has-children', $item->classes ) ) {

                $args->before = '<div class="link-icon-wrapper">';
                $args->after  = joyce_get_theme_svg( 'chevron-down' ) . '</div>';

            } else {

                $args->before = '';
                $args->after  = '';

            }

        }

        return $args;

    }

endif;

add_filter( 'nav_menu_item_args', 'joyce_sub_menu_toggle_button', 10, 3 );

/**
 * Joyce SVG Icon helper functions
 *
 * @package Joyce
 * @since 1.0.0
 */
if ( ! function_exists( 'joyce_the_theme_svg' ) ):
    /**
     * Output and Get Theme SVG.
     * Output and get the SVG markup for an icon in the Joyce_SVG_Icons class.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function joyce_the_theme_svg( $svg_name, $return = false ) {

        if( $return ){

            return joyce_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in joyce_get_theme_svg();.

        }else{

            echo joyce_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in joyce_get_theme_svg();.

        }
    }

endif;

if ( ! function_exists( 'joyce_get_theme_svg' ) ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function joyce_get_theme_svg( $svg_name ) {

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            Joyce_SVG_Icons::get_svg( $svg_name ),
            array(
                'svg'     => array(
                    'class'       => true,
                    'xmlns'       => true,
                    'width'       => true,
                    'height'      => true,
                    'viewbox'     => true,
                    'aria-hidden' => true,
                    'role'        => true,
                    'focusable'   => true,
                ),
                'path'    => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'd'         => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'points'    => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );
        if ( ! $svg ) {
            return false;
        }
        return $svg;

    }

endif;


if( !function_exists( 'joyce_post_category_list' ) ) :

    // Post Category List.
    function joyce_post_category_list( $select_cat = true ){

        $post_cat_lists = get_categories(
            array(
                'hide_empty' => '0',
                'exclude' => '1',
            )
        );

        $post_cat_cat_array = array();
        if( $select_cat ){

            $post_cat_cat_array[''] = esc_html__( '-- Select Category --','joyce' );

        }

        foreach ( $post_cat_lists as $post_cat_list ) {

            $post_cat_cat_array[$post_cat_list->slug] = $post_cat_list->name;

        }

        return $post_cat_cat_array;
    }

endif;

if( !function_exists('joyce_sanitize_meta_pagination') ):

    /** Sanitize Enable Disable Checkbox **/
    function joyce_sanitize_meta_pagination( $input ) {

        $valid_keys = array('global-layout','no-navigation','theme-normal-navigation','ajax-next-post-load');
        if ( in_array( $input , $valid_keys ) ) {
            return $input;
        }
        return '';

    }

endif;

if( !function_exists('joyce_disable_post_views') ):

    /** Disable Post Views **/
    function joyce_disable_post_views() {

        add_filter('booster_extension_filter_views_ed', 'joyce_disable_post_views_callback');

    }

endif;

if( !function_exists('joyce_disable_post_views_callback') ):

    /** Disable Reaction **/
    function joyce_disable_post_views_callback() {

        return false;

    }

endif;

if( !function_exists('joyce_disable_post_read_time') ):

    /** Disable Read Time **/
    function joyce_disable_post_read_time() {

        add_filter('booster_extension_filter_readtime_ed', 'joyce_disable_post_read_time_callback');

    }

endif;

if( !function_exists('joyce_disable_post_read_time_callback') ):

    /** Disable Reaction **/
    function joyce_disable_post_read_time_callback() {

        return false;

    }

endif;

if( !function_exists('joyce_disable_post_like_dislike') ):

    /** Disable Like Dislike **/
    function joyce_disable_post_like_dislike() {

        add_filter('booster_extension_filter_like_ed', 'joyce_disable_post_like_dislike_callback');

    }

endif;

if( !function_exists('joyce_disable_post_like_dislike_callback') ):

    /** Disable Reaction **/
    function joyce_disable_post_like_dislike_callback() {

        return false;

    }

endif;

if( !function_exists('joyce_disable_post_author_box') ):

    /** Disable Author Box **/
    function joyce_disable_post_author_box() {

        add_filter('booster_extension_filter_ab_ed', 'joyce_disable_post_author_box_callback');

    }

endif;

if( !function_exists('joyce_disable_post_author_box_callback') ):

    /** Disable Reaction **/
    function joyce_disable_post_author_box_callback() {

        return false;

    }

endif;

add_filter('booster_extension_filter_ss_ed', 'joyce_disable_post_social_share_callback');

if( !function_exists('joyce_disable_post_social_share_callback') ):

    /** Disable Reaction **/
    function joyce_disable_post_social_share_callback() {

        return false;

    }

endif;

if( !function_exists('joyce_disable_post_reaction') ):

    /** Disable Reaction **/
    function joyce_disable_post_reaction() {

        add_filter( 'booster_extension_filter_reaction_ed', 'joyce_disable_post_reaction_callback' );

    }

endif;

if( !function_exists('joyce_disable_post_reaction_callback') ):

    /** Disable Reaction **/
    function joyce_disable_post_reaction_callback() {

        return false;

    }

endif;

if( !function_exists('joyce_post_floating_nav') ):

    function joyce_post_floating_nav(){

        $joyce_default = joyce_get_default_theme_options();
        $ed_floating_next_previous_nav = get_theme_mod( 'ed_floating_next_previous_nav',$joyce_default['ed_floating_next_previous_nav'] );

        if( 'post' === get_post_type() && $ed_floating_next_previous_nav ){

            $next_post = get_next_post();
            $prev_post = get_previous_post();

            if( isset( $prev_post->ID ) ){

                $prev_link = get_permalink( $prev_post->ID );?>

                <div class="floating-post-navigation floating-navigation-prev">

                    <?php if( get_the_post_thumbnail( $prev_post->ID,'medium_large' ) ){ ?>
                            <?php echo wp_kses_post( get_the_post_thumbnail( $prev_post->ID,'medium_large' ) ); ?>
                    <?php } ?>

                    <a href="<?php echo esc_url( $prev_link ); ?>">
                        <span class="floating-navigation-label"><?php echo esc_html__('Previous post', 'joyce'); ?></span>
                        <span class="floating-navigation-title"><?php echo esc_html( get_the_title( $prev_post->ID ) ); ?></span>
                    </a>

                </div>

            <?php }

            if( isset( $next_post->ID ) ){

                $next_link = get_permalink( $next_post->ID );?>

                <div class="floating-post-navigation floating-navigation-next">

                    <?php if( get_the_post_thumbnail( $next_post->ID,'medium_large' ) ){ ?>
                        <?php echo wp_kses_post( get_the_post_thumbnail( $next_post->ID,'medium_large' ) ); ?>
                    <?php } ?>

                    <a href="<?php echo esc_url( $next_link ); ?>">
                        <span class="floating-navigation-label"><?php echo esc_html__('Next post', 'joyce'); ?></span>
                        <span class="floating-navigation-title"><?php echo esc_html( get_the_title( $next_post->ID ) ); ?></span>
                    </a>

                </div>

            <?php
            }

        }

    }

endif;

add_action( 'joyce_navigation_action','joyce_post_floating_nav',10 );

if( !function_exists('joyce_single_post_navigation') ):

    function joyce_single_post_navigation(){

        $joyce_default = joyce_get_default_theme_options();
        $twp_navigation_type = esc_attr( get_post_meta( get_the_ID(), 'twp_disable_ajax_load_next_post', true ) );
        $current_id = '';
        $article_wrap_class = '';
        global $post;
        $current_id = $post->ID;
        if( $twp_navigation_type == '' || $twp_navigation_type == 'global-layout' ){
            $twp_navigation_type = get_theme_mod('twp_navigation_type', $joyce_default['twp_navigation_type']);
        }

        if( $twp_navigation_type != 'no-navigation' && 'post' === get_post_type() ){ ?>
            <div class="singular-block singular-lower-block">
                <div class="wrapper">
                    <div class="column-row">
                        <div class="column column-12">
                            <?php if( $twp_navigation_type == 'theme-normal-navigation' ){ ?>

                                <div class="navigation-wrapper">
                                    <hr class="styled-separator styled-separator-top" aria-hidden="true">
                                    <?php
                                    // Previous/next post navigation.
                                    the_post_navigation(array(
                                        'prev_text' => '<span class="arrow" aria-hidden="true">' . joyce_the_theme_svg('arrow-left',$return = true ) . '</span><span class="screen-reader-text">' . esc_html__('Previous post:', 'joyce') . '</span><span class="post-title">%title</span>',
                                        'next_text' => '<span class="arrow" aria-hidden="true">' . joyce_the_theme_svg('arrow-right',$return = true ) . '</span><span class="screen-reader-text">' . esc_html__('Next post:', 'joyce') . '</span><span class="post-title">%title</span>',
                                    )); ?>
                                    <hr class="styled-separator styled-separator-bottom" aria-hidden="true">
                                </div>
                                <?php

                            }else{

                                $next_post = get_next_post();
                                if( isset( $next_post->ID ) ){

                                    $next_post_id = $next_post->ID;
                                    echo '<div loop-count="1" next-post="' . absint( $next_post_id ) . '" class="twp-single-infinity"></div>';

                                }
                            } ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php }

    }

endif;

add_action( 'joyce_navigation_action_pagnation','joyce_single_post_navigation',30 );

if ( ! function_exists( 'joyce_header_toggle_search' ) ):

    /**
     * Header Search
     **/
    function joyce_header_toggle_search() {

        $joyce_default = joyce_get_default_theme_options();
        $ed_header_search = get_theme_mod('ed_header_search', $joyce_default['ed_header_search']);
        if( $ed_header_search ){ ?>
            <div class="header-searchbar">
                <div class="header-searchbar-inner">
                    <div class="wrapper">
                        <div class="header-searchbar-area">
                            <a href="javascript:void(0)" class="skip-link-search-start"></a>
                            <?php get_search_form(); ?>
                            <button type="button" id="search-closer" class="close-popup">
                                <?php joyce_the_theme_svg('cross'); ?>
                            </button>
                            <a href="javascript:void(0)" class="skip-link-search-end"></a>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        }

    }

endif;

add_action( 'joyce_before_footer_content_action','joyce_header_toggle_search',10 );


if( !function_exists('joyce_content_offcanvas') ):

    // Offcanvas Contents
    function joyce_content_offcanvas(){ ?>

        <div id="offcanvas-menu">
            <div class="offcanvas-wraper">
                <div class="close-offcanvas-menu">
                    <div class="offcanvas-close">
                        <a href="javascript:void(0)" class="skip-link-menu-start"></a>
                        <button type="button" class="button-offcanvas-close">
                            <span class="offcanvas-close-label">
                                <?php echo esc_html__('Close', 'joyce'); ?>
                            </span>
                        </button>
                    </div>
                </div>
                <div id="primary-nav-offcanvas" class="offcanvas-item offcanvas-main-navigation">
                    <nav class="primary-menu-wrapper" aria-label="<?php esc_attr_e('Horizontal', 'joyce'); ?>" role="navigation">
                        <ul class="primary-menu theme-menu">
                            <?php
                            if (has_nav_menu('joyce-primary-menu')) {
                                wp_nav_menu(
                                    array(
                                        'container' => '',
                                        'items_wrap' => '%3$s',
                                        'theme_location' => 'joyce-primary-menu',
                                        'show_toggles' => true,
                                    )
                                );
                            }else{

                                wp_list_pages(
                                    array(
                                        'match_menu_classes' => true,
                                        'show_sub_menu_icons' => true,
                                        'title_li' => false,
                                        'show_toggles' => true,
                                        'walker' => new Joyce_Walker_Page(),
                                    )
                                );
                            }
                            ?>
                        </ul>
                    </nav><!-- .primary-menu-wrapper -->
                </div>
                <?php if (has_nav_menu('joyce-social-menu')) { ?>
                    <div id="social-nav-offcanvas" class="offcanvas-item offcanvas-social-navigation">
                        <?php wp_nav_menu(array(
                            'theme_location' => 'joyce-social-menu',
                            'link_before' => '<span class="screen-reader-text">',
                            'link_after' => '</span>',
                            'container' => 'div',
                            'container_class' => 'social-menu',
                            'depth' => 1,
                        )); ?>
                    </div>
                <?php } ?>

                <a href="javascript:void(0)" class="skip-link-menu-end"></a>
            </div>
        </div>

    <?php
    }

endif;

add_action( 'joyce_before_footer_content_action','joyce_content_offcanvas',30 );

if( !function_exists('joyce_footer_content_widget') ):

    function joyce_footer_content_widget(){

        $joyce_default = joyce_get_default_theme_options();
        if (is_active_sidebar('joyce-footer-widget-0') ||
            is_active_sidebar('joyce-footer-widget-1') ||
            is_active_sidebar('joyce-footer-widget-2')):
            $x = 1;
            $footer_sidebar = 0;
            do {
                if ($x == 3 && is_active_sidebar('joyce-footer-widget-2')) {
                    $footer_sidebar++;
                }
                if ($x == 2 && is_active_sidebar('joyce-footer-widget-1')) {
                    $footer_sidebar++;
                }
                if ($x == 1 && is_active_sidebar('joyce-footer-widget-0')) {
                    $footer_sidebar++;
                }
                $x++;
            } while ($x <= 3);
            if ($footer_sidebar == 1) {
                $footer_sidebar_class = 12;
            } elseif ($footer_sidebar == 2) {
                $footer_sidebar_class = 6;
            } else {
                $footer_sidebar_class = 4;
            }
            $footer_column_layout = absint(get_theme_mod('footer_column_layout', $joyce_default['footer_column_layout'])); ?>

            <div class="footer-widgetarea">
                <div class="wrapper">
                    <div class="column-row">

                        <?php if (is_active_sidebar('joyce-footer-widget-0')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('joyce-footer-widget-0'); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (is_active_sidebar('joyce-footer-widget-1')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('joyce-footer-widget-1'); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (is_active_sidebar('joyce-footer-widget-2')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('joyce-footer-widget-2'); ?>
                            </div>
                        <?php endif; ?>

                    </div>
                </div>
            </div>

        <?php
        endif;

    }

endif;

add_action( 'joyce_footer_content_action','joyce_footer_content_widget',10 );

if( !function_exists('joyce_footer_content_info') ):

    /**
     * Footer Copyright Area
    **/
    function joyce_footer_content_info(){

        $joyce_default = joyce_get_default_theme_options(); ?>
        <div class="site-info">
            <div class="wrapper">
                <div class="column-row">

                    <div class="column column-10">
                        <div class="footer-credits">

                            <div class="footer-copyright">

                                <?php
                                $footer_copyright_text = wp_kses_post( get_theme_mod( 'footer_copyright_text', $joyce_default['footer_copyright_text'] ) );
                                echo esc_html__('Copyright ', 'joyce') . '&copy ' . absint(date('Y')) . ' <a href="' . esc_url(home_url('/')) . '" title="' . esc_attr(get_bloginfo('name', 'display')) . '" ><span>' . esc_html( get_bloginfo( 'name', 'display' ) ) . '. </span></a> ' . esc_html( $footer_copyright_text );

                                
                                    echo '<br>';
                                    echo esc_html__('Theme: ', 'joyce') . 'Joyce ' . esc_html__('By ', 'joyce') . '<a href="' . esc_url('https://www.themeinwp.com/theme/joyce') . '"  title="' . esc_attr__('Themeinwp', 'joyce') . '" target="_blank" rel="author"><span>' . esc_html__('Themeinwp. ', 'joyce') . '</span></a>';
                                    echo esc_html__('Powered by ', 'joyce') . '<a href="' . esc_url('https://wordpress.org') . '" title="' . esc_attr__('WordPress', 'joyce') . '" target="_blank"><span>' . esc_html__('WordPress.', 'joyce') . '</span></a>';
                                 ?>

                            </div>
                        </div>
                    </div>


                    <div class="column column-2">
                        <a class="to-the-top" href="#site-header">
                            <span class="to-the-top-long">
                                <?php
                                printf( esc_html__( 'To the top %s', 'joyce' ), '<span class="arrow" aria-hidden="true">&uarr;</span>' );
                                ?>
                            </span>
                            <span class="to-the-top-short">
                                <?php
                                printf( esc_html__( 'Up %s', 'joyce' ), '<span class="arrow" aria-hidden="true">&uarr;</span>' );
                                ?>
                            </span>
                        </a>

                    </div>


                </div>
            </div>
        </div>

    <?php
    }

endif;

add_action( 'joyce_footer_content_action','joyce_footer_content_info',20 );

if( !function_exists('joyce_color_scheme_color') ):

    function joyce_color_scheme_color( $current_color ){

        $joyce_default = joyce_get_default_theme_options();

        $colors_scheme = array(

            'default' => array(

                'background_color' => $joyce_default['joyce_background_color'],
                'joyce_bg_color_1' => $joyce_default['joyce_joyce_bg_color_1'],
                'joyce_bg_color_2' => $joyce_default['joyce_joyce_bg_color_2'],
                'joyce_bg_color_3' => $joyce_default['joyce_joyce_bg_color_3'],
                'joyce_bg_color_4' => $joyce_default['joyce_joyce_bg_color_4'],
                'joyce_primary_color' =>  $joyce_default['joyce_primary_color'],
                'joyce_secondary_color' =>  $joyce_default['joyce_secondary_color'],

            ),

            'dark' => array(

                'background_color' => $joyce_default['joyce_background_color_dark'],
                'joyce_bg_color_dark_1' => $joyce_default['joyce_joyce_bg_color_dark_1'],
                'joyce_bg_color_dark_2' => $joyce_default['joyce_joyce_bg_color_dark_2'],
                'joyce_bg_color_dark_3' => $joyce_default['joyce_joyce_bg_color_dark_3'],
                'joyce_bg_color_dark_4' => $joyce_default['joyce_joyce_bg_color_dark_4'],
                'joyce_primary_color' =>  $joyce_default['joyce_primary_color_dark'],
                'joyce_secondary_color' =>  $joyce_default['joyce_secondary_color_dark'],

            ),

        );

        if( isset( $colors_scheme[$current_color] ) ){

            return $colors_scheme[$current_color];

        }

        return;

    }

endif;



if ( ! function_exists( 'joyce_color_scheme_color_action' ) ) :
    function joyce_color_scheme_color_action() {

        if( isset( $_POST['currentColor'] ) && sanitize_text_field( wp_unslash( $_POST['currentColor'] ) ) ){

            $current_color = sanitize_text_field( wp_unslash( $_POST['currentColor'] ) );

            $color_schemes = joyce_color_scheme_color( $current_color );

            if ( $color_schemes ) {
                echo json_encode( $color_schemes );
            }
        }

        wp_die();

    }

endif;

add_action( 'wp_ajax_nopriv_joyce_color_scheme_color', 'joyce_color_scheme_color_action' );
add_action( 'wp_ajax_joyce_color_scheme_color', 'joyce_color_scheme_color_action' );

if( !function_exists( 'joyce_fonts_url' ) ) :

    //Google Fonts URL
    function joyce_fonts_url(){

        $fonts_url = '';
        $fonts = array();
        $joyce_font = 'Gilda+Display&family=Open+Sans:ital,wght@0,300;0,400;0,500;0,600;0,700;1,300;1,400;1,500;1,600;1,700&display=swap';

        $joyce_fonts = array();
        $joyce_fonts[] = $joyce_font;
        $joyce_fonts_stylesheet = '//fonts.googleapis.com/css?family=';

        $i = 0;
        for ( $i = 0; $i < count( $joyce_fonts ); $i++ ) {

            if ( 'off' !== sprintf( _x( 'on', '%s font: on or off', 'joyce' ), $joyce_fonts[$i] ) ) {
                $fonts[] = $joyce_fonts[$i];
            }

        }

        if( $fonts ){

            $fonts_url = add_query_arg( array(
                'family' => urldecode( implode( '|', $fonts ) ),
            ), 'https://fonts.googleapis.com/css' );

        }

        return esc_url_raw( $fonts_url );
    }

endif;

if( !function_exists( 'joyce_main_slider' ) ) :

    function joyce_main_slider(){

        $joyce_default = joyce_get_default_theme_options();
        $ed_header_banner = get_theme_mod( 'ed_header_banner', $joyce_default['ed_header_banner'] );
        $joyce_header_banner_cat = get_theme_mod( 'joyce_header_banner_cat' );

        if( $ed_header_banner ){

            $rtl = '';
            if( is_rtl() ){
                $rtl = 'dir="rtl"';
            }

          $banner_query = new WP_Query( array('post_type' => 'post', 'posts_per_page' => 4,'post__not_in' => get_option("sticky_posts"), 'category_name' => esc_html( $joyce_header_banner_cat ) ) );

          if( $banner_query->have_posts() ): ?>

            <section class="theme-block theme-banner-section">
                <div class="main-banner-wrapper">
                    <div class="swiper-container theme-main-slider swiper-container" <?php echo $rtl; ?>>

                        <div class="swiper-wrapper">

                          <?php
                          while( $banner_query->have_posts() ):
                            $banner_query->the_post();
                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'large'); ?>

                            <div class="swiper-slide">
                                <div class="wrapper-fluid">
                                    <div class="column-row column-row-collapse">
                                        <div class="column column-6 column-sm-12">
                                            <div class="main-banner-image">
                                                <div class="data-bg data-bg-large" data-background="<?php echo esc_url( $featured_image[0] ); ?>">
                                                    <a href="<?php the_permalink(); ?>" class="theme-responsive-image" tabindex="0"></a>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="column column-6 column-sm-12">
                                            <div class="main-banner-content">


                                                <div class="post-content ">

                                                    <header class="entry-header">
                                                        <h2 class="entry-title entry-title-large">
                                                            <a href="<?php the_permalink(); ?>" rel="bookmark">
                                                                <?php the_title(); ?>
                                                            </a>
                                                        </h2>
                                                    </header>

                                                    <div class="post-content-inner">

                                                    <div class="entry-meta">
                                                        <?php
                                                        joyce_posted_by($icon = true, $animation_class = 'theme-animate-up');
                                                        joyce_posted_on($icon = true, $animation_class = 'theme-animate-up');
                                                        ?>
                                                    </div>


                                                    <div class="entry-content hidden-xs-screen">
                                                        <?php
                                                        if (has_excerpt()) {

                                                            the_excerpt();

                                                        } else {

                                                            echo esc_html(wp_trim_words(get_the_content(), 25, '...'));

                                                        } ?>
                                                    </div>


                                                    <div class="hidden-xs-screen">
                                                        <a href="<?php the_permalink(); ?>" rel="bookmark"
                                                           class="continue-reading-btn">
                                                            <span class="btn-arrow"></span>
                                                            <span class="btn-arrow-text"><?php esc_html_e('Read More', 'joyce'); ?></span>
                                                        </a>
                                                    </div>

                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>

                          <?php endwhile; ?>

                        </div>

                        <!-- Control -->
                        <div class="theme-swiper-control swiper-control">
                            <div class="swiper-button-prev"></div>
                            <div class="swiper-pagination"></div>
                            <div class="swiper-button-next"></div>
                        </div>

                    </div>
                </div>
            </section>

          <?php
          wp_reset_postdata();
          endif;

        }

    }

endif;

if( !function_exists( 'joyce_main_carousel' ) ) :

    function joyce_main_carousel(){

        $joyce_default = joyce_get_default_theme_options();
        $ed_carousel_section = get_theme_mod( 'ed_carousel_section', $joyce_default['ed_carousel_section'] );
        $joyce_carousel_section_title = get_theme_mod( 'joyce_carousel_section_title', $joyce_default['joyce_carousel_section_title'] );
        $joyce_carousel_section_cat = get_theme_mod( 'joyce_carousel_section_cat' );

        if( $ed_carousel_section ){

            $rtl = '';
            if( is_rtl() ){
                $rtl = 'dir="rtl"';
            }

            $banner_query = new WP_Query( array('post_type' => 'post', 'posts_per_page' => 10,'post__not_in' => get_option("sticky_posts"), 'category_name' => esc_html( $joyce_carousel_section_cat ) ) );

            if( $banner_query->have_posts() ): ?>

            <section class="theme-block theme-recommendation-section">
                <div class="theme-block-inner-bg theme-block-bg-2"></div>
                <div class="theme-recommendation-main">
                    <div class="wrapper">
                        <div class="theme-area-header">
                            <div class="theme-area-headlines">
                                <h2 class="theme-block-title theme-block-title-primary theme-block-title-medium"><?php echo esc_html($joyce_carousel_section_title); ?></h2>
                            </div>
                            <div class="theme-carousel-control">
                                <div class="twp-carousel-prev"><?php joyce_the_theme_svg('chevron-left') ?></div>
                                <div class="swiper-pagination"></div>
                                <div class="twp-carousel-next"><?php joyce_the_theme_svg('chevron-right') ?></div>
                            </div>
                        </div>
                    </div>
                    <div class="wrapper-fluid">
                        <div class="swiper-container twp-carousel-slider" <?php echo $rtl; ?>>
                            <div class="swiper-wrapper">
                                <?php
                                while ($banner_query->have_posts()):
                                    $banner_query->the_post();
                                    $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'large'); ?>

                                    <div class="swiper-slide swiper-slide-item">
                                        <article id="post-<?php the_ID(); ?>" <?php post_class('theme-article-post theme-carousel-post'); ?>>

                                            <div class="data-bg data-bg-medium" data-background="<?php echo esc_url($featured_image[0]); ?>">
                                                <a href="<?php the_permalink(); ?>" class="theme-responsive-image" tabindex="0"></a>
                                            </div>

                                            <div class="entry-meta">

                                                <?php
                                                joyce_entry_footer($cats = true, $tags = false, $edits = false);
                                                ?>

                                            </div>

                                            <h2 class="entry-title entry-title-big">
                                                <a href="<?php the_permalink(); ?>">
                                                    <?php the_title(); ?>
                                                </a>
                                            </h2>

                                            <div class="entry-meta">

                                                <?php
                                                joyce_posted_by();
                                                joyce_posted_on();
                                                ?>

                                            </div>


                                        </article>

                                    </div>


                                <?php endwhile; ?>

                            </div>
                        </div>

                    </div>
                </div>
            </section>

          <?php
          wp_reset_postdata();
          endif;

        }

    }

endif;

if( !function_exists( 'joyce_category_section' ) ) :

    function joyce_category_section(){
        $joyce_default = joyce_get_default_theme_options();
        $ed_category_section = get_theme_mod( 'ed_category_section', $joyce_default['ed_category_section'] );
        if ($ed_category_section) { ?>
            <div class="theme-block theme-block-space-small theme-block-categories">
                <div class="wrapper">
                    <div class="theme-categories-panels">
                        <div class="column-row">
                            <?php for ($i=1; $i <= 3; $i++) { 
                                $joyce_get_cat_id = absint(get_theme_mod('select_category_for_cat_list_'.$i));
                                $twp_term_image = get_term_meta( $joyce_get_cat_id, 'twp-term-featured-image', true );
                                $twp_cat_link = get_category_link($joyce_get_cat_id);
                                ?>
                                <div class="column column-4 column-sm-12">
                                    <div class="categories-panel">
                                        <div class="category-panel-image data-bg data-bg-small" data-background="<?php echo esc_url($twp_term_image); ?>">
                                            <?php if ( get_theme_mod('ed_category_image_overlay') == 1) { ?>
                                                <div class="data-bg-overlay"></div>
                                            <?php } ?>
                                        </div>

                                        <div class="categories-panel-content">
                                            <h3 class="theme-block-title theme-block-title-primary">
                                                <a href="<?php echo esc_url($twp_cat_link); ?>">
                                                    <?php echo esc_html(get_cat_name( $joyce_get_cat_id));?>
                                                </a>
                                            </h3>
                                        </div>
                                    </div>
                                </div>
                            <?php  } ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php }
    }

endif;




if( !function_exists( 'joyce_about_section' ) ) :

    function joyce_about_section(){
        $joyce_default = joyce_get_default_theme_options();
        $ed_about_section = get_theme_mod( 'ed_about_section', $joyce_default['ed_about_section'] );
        $homepage_about_title = get_theme_mod( 'about_section_title',$joyce_default['about_section_title'] );
        if ($ed_about_section) {
        $joyce_about_page = esc_attr(get_theme_mod('select_page_for_about'));
        if (!empty($joyce_about_page)) {
            $joyce_about_page_args = array(
                'post_type' => 'page',
                'page_id' => $joyce_about_page,
            );
        }
        if (!empty($joyce_about_page_args)) {
            $joyce_about_page_query = new WP_Query($joyce_about_page_args);
            while ($joyce_about_page_query->have_posts()): $joyce_about_page_query->the_post();
                if (has_post_thumbnail()) { 
                    $thumb = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'full');
                    $url = $thumb['0'];
                }
                ?>

                <div class="theme-block theme-block-bg-1 theme-block-space-top theme-block-about">
                    <div class="wrapper">
                        <div class="column-row column-row-center">

                            <div class="column column-3 column-sm-12">
                                <div class="theme-area-headlines">
                                    <h2 class="theme-block-title theme-block-title-primary">
                                        <?php echo esc_html($homepage_about_title); ?>
                                    </h2>
                                    <h3 class="theme-block-title theme-block-title-secondary theme-block-title-large">
                                        <a href="<?php the_permalink();?>">
                                            <?php the_title(); ?>
                                        </a>
                                    </h3>
                                </div>
                            </div>


                            <?php if (has_post_thumbnail()) {
                                $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium_large');
                                $featured_image = isset($featured_image[0]) ? $featured_image[0] : ''; ?>
                                <div class="column column-5 column-sm-12">
                                    <div class="entry-thumbnail" data-aos="fade-up">
                                        <a href="<?php the_permalink(); ?>">
                                            <span class="data-bg data-bg-large" data-background="<?php echo esc_url($featured_image); ?>"></span>
                                        </a>
                                    </div>
                                </div>
                            <?php } ?>

                            <div class="column column-4 column-sm-12">
                                <div class="post-content">
                                    <?php if (has_excerpt()) {
                                        the_excerpt();
                                        joyce_read_more_page_render();
                                        
                                    } else {
                                        the_excerpt();
                                        
                                    } ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

            <?php endwhile;
            wp_reset_postdata();
        }
        }
    }

endif;



if( !function_exists( 'joyce_testimonial_section' ) ) :

    function joyce_testimonial_section(){

        $joyce_default = joyce_get_default_theme_options();
        $ed_testimonial_section = get_theme_mod( 'ed_testimonial_section', $joyce_default['ed_testimonial_section'] );
        if ($ed_testimonial_section) {
        $number_of_testimonial = get_theme_mod( 'number_of_testimonial', $joyce_default['number_of_testimonial'] );

            $joyce_testimonial_page = array();
            for ($i = 1; $i <= $number_of_testimonial; $i++) {
                $joyce_testimonial_page_list = get_theme_mod('select_page_for_testimonial_' . $i);
                if (!empty($joyce_testimonial_page_list)) {
                    $joyce_testimonial_page[] = $joyce_testimonial_page_list;
                }
            }

            // Bail if no valid pages are selected.
            if (empty($joyce_testimonial_page)) {
                return;
            }
            /*page query*/
            $joyce_testimonial_args = array(
                'posts_per_page' => esc_attr($number_of_testimonial),
                'orderby' => 'post__in',
                'post_type' => 'page',
                'post__in' => $joyce_testimonial_page,
            );
                $joyce_testimonial_query = new WP_Query($joyce_testimonial_args); ?>
                <div class="theme-block theme-block-space-large theme-block-testimonials theme-block-bg-3">
                    <div class="wrapper">
                        <h2 class="theme-block-title theme-block-title-primary heme-block-title-large text-center">
                            <?php echo wp_kses_post(get_theme_mod('testimonial_section_title')); ?>
                        </h2>
                        <hr class="styled-separator styled-separator-top" aria-hidden="true">
                        <div class="theme-testimonial-area">
                            <div class="column-row column-row-collapse">
                            <?php
                            $i = 1;
                            $j = 1;
                            if ($joyce_testimonial_query->have_posts()) :
                                while ($joyce_testimonial_query->have_posts()) : $joyce_testimonial_query->the_post();
                                    if (has_post_thumbnail()) {
                                        $thumb = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'medium_large');
                                        $url = $thumb['0'];
                                    } else {
                                        $url = '';
                                    }
                                    if ($j == 1 || $j == 2) {
                                        $joyce_column = "column-order-1";
                                        $joyce_column_2 = "column-order-2";
                                    }else{
                                        $joyce_column = "column-order-2";
                                        $joyce_column_2 = "column-order-1";
                                    }
                                    if ($j == 4) {
                                        $j = 1;
                                    }else {
                                        $j++;
                                    }
                                    ?>
                                    <div class="column column-6 column-xs-12 <?php if ($i % 2 == 0) { echo 'column-even'; } else { echo 'column-odd'; } ?>">
                                        <div class="theme-testimonial-article">
                                            <div class="column-row column-row-collapse">
                                                <?php if (!empty($url)) { ?>
                                                        <div class="column column-6 column-sm-12 <?php echo $joyce_column; ?>">
                                                            <div class="testimonial-image">
                                                                <div class="data-bg data-bg-medium" data-background="<?php echo esc_url($url); ?>">
                                                                    <a href="<?php the_permalink(); ?>" class="theme-responsive-image" tabindex="0"></a>
                                                                </div>
                                                            </div>
                                                        </div>
                                                <?php }?>
                                                <div class="column column-6 column-sm-12 <?php echo $joyce_column_2; ?>">
                                                    <div class="testimonial-content">
                                                        <h3 class="testimonial-title ">
                                                            <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                                        </h3>
                                                        <div class="testimonial-caption">
                                                            <?php if (has_excerpt()) {
                                                                the_excerpt();
                                                                joyce_read_more_page_render();
                                                            } else {
                                                                the_excerpt();
                                                            } ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                    <?php
                                    $i++;
                                endwhile;
                                wp_reset_postdata();
                            endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
        <?php }
    }

endif;



if( !function_exists( 'joyce_cta_section' ) ) :

    function joyce_cta_section(){
        $joyce_default = joyce_get_default_theme_options();
        $ed_cta_section = get_theme_mod( 'ed_cta_section', $joyce_default['ed_cta_section'] );
        $ed_cta_post_excerpt = get_theme_mod( 'ed_cta_post_excerpt', $joyce_default['ed_cta_post_excerpt'] );
        if ($ed_cta_section) {
        $joyce_cta_page = esc_attr(get_theme_mod('select_page_for_cta'));
        if (!empty($joyce_cta_page)) {
            $joyce_cta_page_args = array(
                'post_type' => 'page',
                'page_id' => $joyce_cta_page,
            );
        }
        $homepage_cta_button_text = get_theme_mod( 'homepage_cta_button_text',$joyce_default['homepage_cta_button_text'] );
        $homepage_cta_button_text_url = get_theme_mod( 'homepage_cta_button_text_url',$joyce_default['homepage_cta_button_text_url'] );
        $cta_link_tab = get_theme_mod( 'cta_link_tab',$joyce_default['cta_link_tab'] );
        $ed_cta_image_overlay = get_theme_mod( 'ed_cta_image_overlay',$joyce_default['ed_cta_image_overlay'] );
        $cta_block_spacing = get_theme_mod( 'cta_block_spacing',$joyce_default['cta_block_spacing'] );
        $cta_block_layout = get_theme_mod( 'cta_block_layout',$joyce_default['cta_block_layout'] );
        if (!empty($joyce_cta_page_args)) {
            $joyce_cta_page_query = new WP_Query($joyce_cta_page_args);
            while ($joyce_cta_page_query->have_posts()): $joyce_cta_page_query->the_post();
                $thumb = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'full');
                $url = isset($thumb[0]) ? $thumb[0] : ''; 

                ?>
                <div class="theme-block <?php echo esc_attr($cta_block_spacing); ?> theme-block-cta">
                    <div class="<?php echo esc_attr($cta_block_layout); ?>">
                        <div class="theme-cta-panel <?php if ($url) { echo 'data-bg'; } ?>" data-background="<?php echo esc_url($url); ?>">
                            <?php if ($ed_cta_image_overlay) { ?>
                                <div class="data-bg-overlay"></div>
                            <?php } ?>

                            <div class="cta-panel">
                                <h2 class="theme-block-title theme-block-title-secondary theme-block-title-large">
                                    <?php the_title(); ?>
                                </h2>

                                <hr class="styled-separator styled-separator-top" aria-hidden="true">

                                <?php if ($ed_cta_post_excerpt) { ?>
                                    <div class="cta-panel-content">
                                        <?php the_excerpt(); ?>
                                    </div>
                                <?php } ?>

                                <?php
                                if ($homepage_cta_button_text) { ?>
                                    <div class="theme-block-link">
                                        <a href="<?php echo esc_url($homepage_cta_button_text_url); ?>"
                                           class="theme-button"
                                           <?php if ($cta_link_tab){ ?>target="_blank"<?php } ?>>
                                            <span><?php echo esc_html($homepage_cta_button_text); ?></span>
                                            <span><?php joyce_the_theme_svg('arrow-right'); ?></span>
                                        </a>
                                    </div>
                                <?php } ?>
                            </div>
                        </div>
                    </div>

                </div>
            <?php endwhile;
            wp_reset_postdata();
        }
        }
    }

endif;




if( !function_exists( 'joyce_contact_section' ) ) :

    function joyce_contact_section(){
        $joyce_default = joyce_get_default_theme_options();
        $ed_contact_section = get_theme_mod( 'ed_contact_section', $joyce_default['ed_contact_section'] );
        $contact_section_title = get_theme_mod( 'contact_section_title', $joyce_default['contact_section_title'] );
        $contact_short_info = get_theme_mod( 'contact_short_info', $joyce_default['contact_short_info'] );
        $contact_section_location = get_theme_mod( 'contact_section_location', $joyce_default['contact_section_location'] );
        $contact_section_email = get_theme_mod( 'contact_section_email', $joyce_default['contact_section_email'] );
        $contact_section_number = get_theme_mod( 'contact_section_number', $joyce_default['contact_section_number'] );
        $contact_form_shortcode = get_theme_mod( 'contact_form_shortcode' );
        $contact_section_bg_image = get_theme_mod( 'contact_section_bg_image');
        if ($ed_contact_section) { ?>

            <div class="theme-block theme-block-bg-4 theme-block-space-top theme-block-contact">
                <div class="wrapper-fluid">
                    <div class="column-row column-row-center">
                        <div class="column column-1 column-sm-12"></div>
                        <div class="column column-3 column-sm-12">
                            <div class="theme-contact-details">
                                <h2 class="theme-block-title theme-block-title-primary">
                                    <?php echo esc_html($contact_section_title); ?>
                                </h2>

                                <ul class="theme-contact-list">
                                    <?php if ($contact_section_location) { ?>
                                        <li class="theme-contact-list-group">
                                            <div class="theme-contact-list-title">
                                                <?php echo esc_html__('Location:', 'joyce') ?>
                                            </div>
                                            <div class="theme-contact-list-content">
                                                <?php echo esc_html($contact_section_location); ?>
                                            </div>
                                        </li>
                                    <?php } ?>
                                    <li class="theme-contact-list-group">
                                        <?php if (!empty($contact_section_number) || !empty($contact_section_email)) { ?>
                                            <div class="theme-contact-list-title">
                                                <?php echo esc_html__('Contact:','joyce') ?>
                                            </div>
                                        <?php } ?>
                                        <div class="theme-contact-list-content">
                                            <?php if ($contact_section_number) { ?>
                                                <div class="contact-list-content-phone">
                                                    <div class="contact-list-content-icon">
                                                    </div>
                                                    <div class="contact-list-content-detail">
                                                        <a href="tel:<?php echo absint($contact_section_number); ?>">
                                                            <?php echo absint($contact_section_number); ?>
                                                        </a>
                                                    </div>

                                                </div>
                                            <?php } ?>
                                            <?php if ($contact_section_email) { ?>
                                                <div class="contact-list-content-email">
                                                    <div class="contact-list-content-icon">
                                                    </div>
                                                    <div class="contact-list-content-detail">
                                                        <a href="mailto:<?php echo sanitize_email($contact_section_email); ?>">
                                                            <?php echo sanitize_email($contact_section_email); ?>
                                                        </a>
                                                    </div>
                                                </div>
                                            <?php } ?>
                                        </div>
                                    </li>

                                    <?php if( has_nav_menu('joyce-social-menu') ){ ?>
                                        <li class="theme-contact-list-group">
                                            <div class="theme-contact-list-title">
                                                <?php echo esc_html__('Follow Us On:','joyce') ?>
                                            </div>

                                            <div class="theme-social-navigation theme-contact-list-content">
                                                <?php wp_nav_menu(array(
                                                    'theme_location' => 'joyce-social-menu',
                                                    'link_before' => '<span class="screen-reader-text">',
                                                    'link_after' => '</span>',
                                                    'container' => 'div',
                                                    'container_class' => 'social-menu',
                                                    'depth' => 1,
                                                )); ?>
                                            </div>
                                        </li>
                                    <?php } ?>
                                </ul>
                            </div>
                        </div>

                        <div class="column column-4 column-sm-12">
                            <?php if ($contact_section_bg_image) { ?>
                                <div class="entry-thumbnail" data-aos="fade-up">
                                    <img src="<?php echo esc_url($contact_section_bg_image); ?>">
                                </div>
                            <?php } ?>
                        </div>

                        <div class="column column-3 column-sm-12">
                            <div class="theme-contact-forms">


                                <h3 class="theme-block-title theme-block-title-secondary theme-block-title-large">
                                    <?php echo esc_html($contact_short_info); ?>
                                </h3>



                                <div class="post-content">
                                    <?php echo do_shortcode($contact_form_shortcode); ?>
                                </div>
                            </div>
                        </div>

                        <div class="column column-1 column-sm-12"></div>
                    </div>
                </div>
            </div>

        <?php }
    }

endif;




if( !function_exists('joyce_404_posts') ):

    function joyce_404_posts(){

        $lead_post_query = new WP_Query( array('post_type' => 'post', 'posts_per_page' => 3,'post__not_in' => get_option("sticky_posts") ) );

        if( $lead_post_query ->have_posts() ): ?>
                <div class="wrapper">
                    <div class="column-row column-row-small">

                        <div class="column column-12 column-sm-12 column-order-2">
                            <div class="column-row column-row-small">

                                <?php
                                while( $lead_post_query->have_posts() ){
                                    $lead_post_query->the_post();

                                    $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'large'); ?>

                                    <div class="column column-4 mb-xs-15 column-xs-12">
                                        <div class="content-main content-main-bg">
                                            <div class="content-list">
                                                <article
                                                        id="theme-post-<?php the_ID(); ?>" <?php post_class('news-article'); ?>>

                                                    <?php if ( isset( $featured_image[0] ) && $featured_image[0]) { ?>
                                                        <div class="post-thumbnail">
                                                            <div class="img-hover-scale">

                                                                <a href="<?php the_permalink(); ?>" tabindex="0">
                                                                    <img title="<?php the_title_attribute(); ?>"
                                                                         alt="<?php the_title_attribute(); ?>"
                                                                         src="<?php echo esc_url($featured_image[0]); ?>">
                                                                </a>

                                                            </div>
                                                        </div>
                                                    <?php } ?>

                                                    <div class="article-content">

                                                        <div class="entry-meta">
                                                            <?php joyce_entry_footer( $cats = true, $tags = false, $edits = false ); ?>
                                                        </div>

                                                        <h3 class="entry-title entry-title-small">
                                                            <a href="<?php the_permalink(); ?>"
                                                               rel="bookmark"><?php the_title(); ?></a>
                                                        </h3>

                                                        <div class="entry-meta">
                                                            <?php joyce_posted_on(); ?>
                                                        </div>

                                                        <div class="entry-content entry-content-muted entry-content-small">

                                                            <?php
                                                            if( has_excerpt() ){

                                                                the_excerpt();

                                                            }else{

                                                                echo esc_html(wp_trim_words(get_the_content(), 20, '...'));

                                                            } ?>

                                                        </div>
                                                    </div>

                                                </article>
                                            </div>
                                        </div>
                                    </div>

                                <?php } ?>

                            </div>
                        </div>

                    </div>
                </div>
        <?php
        wp_reset_postdata();
        endif;

    }

endif;

if( !function_exists('joyce_related_posts') ):

    // Single Posts Related Posts.
    function joyce_related_posts(){

        $joyce_default = joyce_get_default_theme_options();
        $current_id = '';
        $article_wrap_class = '';
        global $post;
        $current_id = $post->ID;

        if( is_single() && 'post' === get_post_type() ){

            $cats = get_the_category( $post->ID );
            $category = array();
            if( $cats ){
                foreach( $cats as $cat ){
                    $category[] = $cat->term_id;
                }
            }

            $related_posts_query = new WP_Query( array( 'post_type' => 'post', 'posts_per_page' => 6, 'post__not_in' => array( $post->ID ), 'category__in' => $category ) );
            $ed_related_post = absint( get_theme_mod( 'ed_related_post',$joyce_default['ed_related_post'] ) );

            if( $ed_related_post && $related_posts_query->have_posts() ): ?>

                <div class="theme-block theme-block-related">

                    <?php $related_post_title = esc_html( get_theme_mod( 'related_post_title',$joyce_default['related_post_title'] ) );
                    if( $related_post_title ){ ?>

                        <h2 class="theme-area-title">
                            <?php echo esc_html( $related_post_title ); ?>
                        </h2>


                    <?php } ?>

                    <div class="related-posts">

                        <?php
                        while( $related_posts_query->have_posts() ):
                            $related_posts_query->the_post();

                            $featured_image = wp_get_attachment_image_src( get_post_thumbnail_id(),'medium_large' ); ?>


                            <article id="post-<?php the_ID(); ?>" <?php post_class('related-post-item theme-article-post'); ?>>
                                <div class="column-row">

                                <?php
                                if( isset( $featured_image[0] ) && has_post_thumbnail() ): ?>
                                    <div class="column column-6 column-sm-12">
                                        <div class="post-thumbnail">

                                            <div class="data-bg data-bg-medium" data-background="<?php echo esc_url( $featured_image[0] ); ?>">
                                                <a href="<?php the_permalink(); ?>" class="theme-responsive-image" tabindex="0"></a>
                                            </div>

                                        </div>
                                    </div>
                                <?php endif; ?>

                                <div class="column column-6 column-sm-12">
                                    <div class="post-content">

                                        <header class="entry-header">
                                            <h3 class="entry-title entry-title-big">
                                                <a href="<?php the_permalink(); ?>" rel="bookmark">
                                                    <?php the_title(); ?>
                                                </a>
                                            </h3>
                                        </header>

                                        <div class="entry-meta">

                                            <?php
                                            joyce_posted_by();
                                            joyce_posted_on();
                                            ?>

                                        </div>

                                        <div class="entry-content entry-content-muted entry-content-small">

                                            <?php
                                            if( has_excerpt() ){

                                                the_excerpt();

                                            }else{

                                                echo esc_html(wp_trim_words(get_the_content(), 20, '...'));

                                            } ?>

                                        </div>

                                    </div>
                                </div>

                            </div>
                                <hr class="styled-separator styled-separator-bottom" aria-hidden="true">
                            </article>

                        <?php endwhile; ?>

                    </div>

                </div>

            <?php
            wp_reset_postdata();
            endif;

        }

    }

endif;
add_action( 'joyce_navigation_action','joyce_related_posts',20 );


if( !function_exists('joyce_read_more_page_render') ):

    function joyce_read_more_page_render(){ ?>

        <div class="mp-read-more">
            <a class="mp-read-more-src" href="<?php the_permalink(); ?>"><?php esc_html_e('Continue reading','joyce'); ?></a>
        </div>

    <?php }
endif;


function joyce_excerpt_more( $link ) {
    if ( is_admin() ) {
        return $link;
    }

    $link = sprintf(
        '<div class="theme-link-more"><a href="%1$s" class="theme-more-link">%2$s '.joyce_the_theme_svg('arrow-right',true).'</a></div>',
        esc_url( get_permalink( get_the_ID() ) ),
        /* translators: %s: Post title. */
        sprintf( __( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'joyce' ), get_the_title( get_the_ID() ) )
    );
    return $link;
}
add_filter( 'excerpt_more', 'joyce_excerpt_more' );
