<?php
/**
 * Joyce Theme Customizer
 *
 * @package Joyce
 */

/** Sanitize Functions. **/
	require get_template_directory() . '/inc/customizer/default.php';

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
if (!function_exists('joyce_customize_register')) :

function joyce_customize_register( $wp_customize ) {

	require get_template_directory() . '/inc/customizer/custom-classes.php';
	require get_template_directory() . '/inc/customizer/sanitize.php';
	require get_template_directory() . '/inc/customizer/preloader.php';
	require get_template_directory() . '/inc/customizer/header.php';
	require get_template_directory() . '/inc/customizer/pagination.php';
	require get_template_directory() . '/inc/customizer/post.php';
	require get_template_directory() . '/inc/customizer/single.php';
	require get_template_directory() . '/inc/customizer/footer.php';
	require get_template_directory() . '/inc/customizer/color-scheme.php';
	require get_template_directory() . '/inc/customizer/homepage-content.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	$wp_customize->get_section( 'static_front_page' )->panel = 'theme_home_pannel';
	$wp_customize->get_section( 'static_front_page' )->title = esc_html__('Homepage Page/Post Option','joyce');
	$wp_customize->get_section( 'colors' )->panel = 'theme_colors_panel';
	$wp_customize->get_section( 'colors' )->title = esc_html__('Color Options','joyce');
	$wp_customize->get_section( 'title_tagline' )->panel = 'theme_general_settings';
	$wp_customize->get_section( 'header_image' )->panel = 'theme_general_settings';
	$wp_customize->get_section( 'background_image' )->panel = 'theme_general_settings';

	if ( isset( $wp_customize->selective_refresh ) ) {
		
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'joyce_customize_partial_blogname',
		) );

		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'joyce_customize_partial_blogdescription',
		) );

	}

	
	$joyce_default = joyce_get_default_theme_options();
	$wp_customize->add_setting('logo_width_range',
	    array(
	        'default'           => $joyce_default['logo_width_range'],
	        'capability'        => 'edit_theme_options',
	        'sanitize_callback' => 'joyce_sanitize_number_range',
	    )
	);
	$wp_customize->add_control('logo_width_range',
	    array(
	        'label'       => esc_html__('Logo With', 'joyce'),
	        'description'       => esc_html__( 'Define logo size min-200 to max-700 (step-20)', 'joyce' ),
	        'section'     => 'title_tagline',
	        'type'        => 'range',
	        'input_attrs' => array(
				           'min'   => 200,
				           'max'   => 700,
				           'step'   => 20,
			        	),
	    )
	);
	
	// Theme Options Panel.
	$wp_customize->add_panel( 'theme_option_panel',
		array(
			'title'      => esc_html__( 'Theme Options', 'joyce' ),
			'priority'   => 150,
			'capability' => 'edit_theme_options',
		)
	);

	$wp_customize->add_panel( 'theme_general_settings',
		array(
			'title'      => esc_html__( 'General Settings', 'joyce' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
		)
	);

	$wp_customize->add_panel( 'theme_colors_panel',
		array(
			'title'      => esc_html__( 'Color Settings', 'joyce' ),
			'priority'   => 15,
			'capability' => 'edit_theme_options',
		)
	);

	// Theme Options Panel.
	$wp_customize->add_panel( 'theme_footer_option_panel',
		array(
			'title'      => esc_html__( 'Footer Setting', 'joyce' ),
			'priority'   => 150,
			'capability' => 'edit_theme_options',
		)
	);

	// Template Options
	$wp_customize->add_panel( 'theme_home_pannel',
		array(
			'title'      => esc_html__( 'Frontpage Settings', 'joyce' ),
			'priority'   => 150,
			'capability' => 'edit_theme_options',
		)
	);


	$joyce_defaults = joyce_get_default_theme_options();
	$home_section_arrange_vals_4 = get_theme_mod( 'home_section_arrange_vals_4', $joyce_defaults['home_section_arrange_vals_4'] );
	$home_section_arrange_vals_4 = explode(",",$home_section_arrange_vals_4 );


	$j = 1;
	foreach( $home_section_arrange_vals_4 as $home_section_arrange ){
	    if ($j <= 5) {
	        $wp_customize->get_section( $home_section_arrange )->priority = $j;
	    }   
	    
	    $j ++;
	}


	// Register custom section types.
	$wp_customize->register_section_type( 'Joyce_Customize_Section_Upsell' );

	// Register sections.
	$wp_customize->add_section(
		new Joyce_Customize_Section_Upsell(
			$wp_customize,
			'theme_upsell',
			array(
				'title'    => esc_html__( 'Joyce Pro', 'joyce' ),
				'pro_text' => esc_html__( 'Upgrade To Pro', 'joyce' ),
				'pro_url'  => esc_url('https://www.themeinwp.com/theme/joyce-pro/'),
				'priority'  => 1,
			)
		)
	);

}

endif;
add_action( 'customize_register', 'joyce_customize_register' );

add_action( 'wp_ajax_joyce_arrange_home_section', 'joyce_arrange_home_section' );
add_action('wp_ajax_nopriv_joyce_arrange_home_section', 'joyce_arrange_home_section');

function joyce_arrange_home_section() {

	if ( isset( $_POST['sections'] ) ) {

		set_theme_mod( 'home_section_arrange_vals_4', wp_unslash( $_POST['sections'] ) );
		
	}
	wp_die(); // this is required to terminate immediately and return a proper response
}


/**
 * Customizer Enqueue scripts and styles.
 */

if (!function_exists('joyce_customizer_scripts')) :

    function joyce_customizer_scripts(){   
    	
    	wp_enqueue_script('jquery-ui-button');
    	wp_enqueue_style('joyce-customizer', get_template_directory_uri() . '/assets/lib/custom/css/customizer.css');
        wp_enqueue_script('joyce-customizer', get_template_directory_uri() . '/assets/lib/custom/js/customizer.js', array('jquery','customize-controls'), '', 1);

    	wp_enqueue_script('joyce-re-customizer', get_template_directory_uri() . '/assets/lib/custom/js/re-customizer.js', array('jquery','customize-controls'), '', 1);

        $ajax_nonce = wp_create_nonce('joyce_ajax_nonce');
        wp_localize_script( 
		    'joyce-customizer', 
		    'joyce_customizer',
		    array(
		        'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
		        'ajax_nonce' => $ajax_nonce,
		     )
		);
        $home_section_arrange_vals_4 = get_theme_mod( 'home_section_arrange_vals_4' );
        $home_section_arrange_vals_4 = explode(",",$home_section_arrange_vals_4 );
        $key_sidebar = '';
        $home_url = esc_url( home_url('/') );

        wp_localize_script( 
		    'joyce-re-customizer', 
		    'joyce_re_customizer',
		    array(
		        'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
		        'ajax_nonce' => $ajax_nonce,
		        'key_sidebar' => $key_sidebar,
		        'home_url' => $home_url,
		     )
		);
    }

endif;

add_action('customize_controls_enqueue_scripts', 'joyce_customizer_scripts');
add_action('customize_controls_init', 'joyce_customizer_scripts');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */

if (!function_exists('joyce_customize_partial_blogname')) :

	function joyce_customize_partial_blogname() {
		bloginfo( 'name' );
	}
endif;

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */

if (!function_exists('joyce_customize_partial_blogdescription')) :

	function joyce_customize_partial_blogdescription() {
		bloginfo( 'description' );
	}

endif;