<?php
/**
* Custom Functions.
*
* @package Joyce
*/

if( !function_exists( 'joyce_sanitize_sidebar_option' ) ) :

    // Sidebar Option Sanitize.
    function joyce_sanitize_sidebar_option( $joyce_input ){

        $joyce_metabox_options = array( 'global-sidebar','left-sidebar','right-sidebar','no-sidebar' );
        if( in_array( $joyce_input,$joyce_metabox_options ) ){

            return $joyce_input;

        }

        return;

    }

endif;

if( !function_exists( 'joyce_sanitize_single_pagination_layout' ) ) :

    // Sidebar Option Sanitize.
    function joyce_sanitize_single_pagination_layout( $joyce_input ){

        $joyce_single_pagination = array( 'no-navigation','theme-normal-navigation','ajax-next-post-load' );
        if( in_array( $joyce_input,$joyce_single_pagination ) ){

            return $joyce_input;

        }

        return;

    }

endif;

if( !function_exists( 'joyce_sanitize_archive_layout' ) ) :

    // Sidebar Option Sanitize.
    function joyce_sanitize_archive_layout( $joyce_input ){

        $joyce_archive_option = array( 'default','full','grid','masonry' );
        if( in_array( $joyce_input,$joyce_archive_option ) ){

            return $joyce_input;

        }

        return;

    }

endif;

if( !function_exists( 'joyce_sanitize_header_layout' ) ) :

    // Sidebar Option Sanitize.
    function joyce_sanitize_header_layout( $joyce_input ){

        $joyce_header_options = array( 'layout-1','layout-2' );
        if( in_array( $joyce_input,$joyce_header_options ) ){

            return $joyce_input;

        }

        return;

    }

endif;

if( !function_exists( 'joyce_sanitize_single_post_layout' ) ) :

    // Single Layout Option Sanitize.
    function joyce_sanitize_single_post_layout( $joyce_input ){

        $joyce_single_layout = array( 'layout-1','layout-2' );
        if( in_array( $joyce_input,$joyce_single_layout ) ){

            return $joyce_input;

        }

        return;

    }

endif;

if ( ! function_exists( 'joyce_sanitize_checkbox' ) ) :

	/**
	 * Sanitize checkbox.
	 */
	function joyce_sanitize_checkbox( $joyce_checked ) {

		return ( ( isset( $joyce_checked ) && true === $joyce_checked ) ? true : false );

	}

endif;


if ( ! function_exists( 'joyce_sanitize_select' ) ) :

    /**
     * Sanitize select.
     */
    function joyce_sanitize_select( $joyce_input, $joyce_setting ) {

        // Ensure input is a slug.
        $joyce_input = sanitize_text_field( $joyce_input );

        // Get list of choices from the control associated with the setting.
        $choices = $joyce_setting->manager->get_control( $joyce_setting->id )->choices;

        // If the input is a valid key, return it; otherwise, return the default.
        return ( array_key_exists( $joyce_input, $choices ) ? $joyce_input : $joyce_setting->default );

    }

endif;

if ( ! function_exists( 'joyce_sanitize_dropdown_pages' ) ) :

    /**
     * Sanitize dropdown pages.
     *
     * @since 1.0.0
     *
     * @param int                  $page_id Page ID.
     * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
     * @return int|string Page ID if the page is published; otherwise, the setting default.
     */
    function joyce_sanitize_dropdown_pages( $page_id, $setting ) {

        // Ensure $input is an absolute integer.
        $page_id = absint( $page_id );

        // If $page_id is an ID of a published page, return it; otherwise, return the default.
        return ( 'publish' === get_post_status( $page_id ) ? $page_id : $setting->default );

    }

endif;


if ( ! function_exists( 'joyce_sanitize_image' ) ) :

    /**
     * Sanitize image.
     *
     * @since 1.0.0
     *
     * @see wp_check_filetype() https://developer.wordpress.org/reference/functions/wp_check_filetype/
     *
     * @param string               $image Image filename.
     * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
     * @return string The image filename if the extension is allowed; otherwise, the setting default.
     */
    function joyce_sanitize_image( $image, $setting ) {

        /**
         * Array of valid image file types.
         *
         * The array includes image mime types that are included in wp_get_mime_types().
        */
        $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon',
        );

        // Return an array with file extension and mime_type.
        $file = wp_check_filetype( $image, $mimes );

        // If $image has a valid mime_type, return it; otherwise, return the default.
        return ( $file['ext'] ? $image : $setting->default );

    }

endif;



if ( ! function_exists( 'joyce_sanitize_number_range' ) ) :

    /**
     * Sanitize number range.
     *
     * @since 1.0.0
     *
     * @see absint() https://developer.wordpress.org/reference/functions/absint/
     *
     * @param int                  $input Number to check within the numeric range defined by the setting.
     * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
     * @return int|string The number, if it is zero or greater and falls within the defined range; otherwise, the setting default.
     */
    function joyce_sanitize_number_range( $input, $setting ) {

        // Ensure input is an absolute integer.
        $input = absint( $input );

        // Get the input attributes associated with the setting.
        $atts = $setting->manager->get_control( $setting->id )->input_attrs;

        // Get min.
        $min = ( isset( $atts['min'] ) ? $atts['min'] : $input );

        // Get max.
        $max = ( isset( $atts['max'] ) ? $atts['max'] : $input );

        // Get Step.
        $step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );

        // If the input is within the valid range, return it; otherwise, return the default.
        return ( $min <= $input && $input <= $max && is_int( $input / $step ) ? $input : $setting->default );

    }

endif;
