<?php
/**
* Sidebar Metabox.
*
* @package Joyce
*/

add_action( 'add_meta_boxes', 'joyce_metabox' );

if( ! function_exists( 'joyce_metabox' ) ):


    function joyce_metabox() {
        
        add_meta_box(
            'twp-custom-metabox',
            esc_html__( 'Single Post Settings', 'joyce' ),
            'joyce_post_metafield_callback',
            'post', 
            'normal', 
            'high'
        );
    }

endif;

$joyce_single_image_layout_options = array(
    'layout-1' => esc_html__( 'Default Layout', 'joyce' ),
    'layout-2' => esc_html__( 'Banner Layout', 'joyce' ),
);


/**
 * Callback function for post option.
*/
if( ! function_exists( 'joyce_post_metafield_callback' ) ):
    
	function joyce_post_metafield_callback() {

		global $post, $joyce_single_image_layout_options;
        $post_type = get_post_type($post->ID);
		wp_nonce_field( basename( __FILE__ ), 'joyce_post_meta_nonce' ); ?>
        
        <div class="metabox-main-block">

            <div class="metabox-navbar">
                <ul>

                    <li>
                        <a id="metabox-navbar-appearance" class="metabox-navbar-active" href="javascript:void(0)">

                            <?php esc_html_e('Appearance Settings', 'joyce'); ?>

                        </a>
                    </li>

                    <?php
                    if( class_exists('Booster_Extension_Class') ){ ?>

                        <li>
                            <a id="twp-tab-booster" href="javascript:void(0)">

                                <?php esc_html_e('Booster Extension Settings', 'joyce'); ?>

                            </a>
                        </li>

                    <?php } ?>

                </ul>
            </div>

            <div class="twp-tab-content">

                <?php if( $post_type == 'post' ): ?>

                    <div id="metabox-navbar-appearance-content" class="metabox-content-wrap metabox-content-wrap-active">

                         <div class="metabox-opt-panel">

                            <h3 class="meta-opt-title"><?php esc_html_e('Navigation Setting','joyce'); ?></h3>

                            <?php
                            $twp_disable_ajax_load_next_post = esc_attr( get_post_meta($post->ID, 'twp_disable_ajax_load_next_post', true) ); ?>
                            <div class="metabox-opt-wrap metabox-opt-wrap-alt">

                                <label><b><?php esc_html_e( 'Navigation Type','joyce' ); ?></b></label>

                                <select name="twp_disable_ajax_load_next_post">

                                    <option <?php if( $twp_disable_ajax_load_next_post == '' || $twp_disable_ajax_load_next_post == 'global-layout' ){ echo 'selected'; } ?> value="global-layout"><?php esc_html_e('Global Layout','joyce'); ?></option>
                                    <option <?php if( $twp_disable_ajax_load_next_post == 'no-navigation' ){ echo 'selected'; } ?> value="no-navigation"><?php esc_html_e('Disable Navigation','joyce'); ?></option>
                                    <option <?php if( $twp_disable_ajax_load_next_post == 'theme-normal-navigation' ){ echo 'selected'; } ?> value="theme-normal-navigation"><?php esc_html_e('Next Previous Navigation','joyce'); ?></option>
                                    <option <?php if( $twp_disable_ajax_load_next_post == 'ajax-next-post-load' ){ echo 'selected'; } ?> value="ajax-next-post-load"><?php esc_html_e('Ajax Load Next 3 Posts Contents','joyce'); ?></option>

                                </select>

                            </div>

                        </div>

                    </div>

                <?php endif; ?>
                

                <div class="metabox-opt-panel">

                    <h3 class="meta-opt-title"><?php esc_html_e('Appearance Layout','joyce'); ?></h3>

                    <div class="metabox-opt-wrap metabox-opt-wrap-alt">

                        <?php
                        $joyce_single_image_layout = esc_html( get_post_meta( $post->ID, 'joyce_single_image_layout', true ) ); 
                        if( $joyce_single_image_layout == '' ){ $joyce_single_image_layout = 'layout-1'; }

                        foreach ( $joyce_single_image_layout_options as $key => $joyce_single_image_layout_option) { ?>

                            <label class="description">
                                <input type="radio" name="joyce_single_image_layout" value="<?php echo esc_attr( $key ); ?>" <?php if( $key == $joyce_single_image_layout ){ echo "checked='checked'";} ?>/>&nbsp;<?php echo esc_html( $joyce_single_image_layout_option ); ?>
                            </label>

                        <?php } ?>

                    </div>

                </div>
                <?php 
                $joyce_ed_post_views = esc_html( get_post_meta( $post->ID, 'joyce_ed_post_views', true ) );
                $joyce_ed_post_read_time = esc_html( get_post_meta( $post->ID, 'joyce_ed_post_read_time', true ) );
                $joyce_ed_post_like_dislike = esc_html( get_post_meta( $post->ID, 'joyce_ed_post_like_dislike', true ) );
                $joyce_ed_post_author_box = esc_html( get_post_meta( $post->ID, 'joyce_ed_post_author_box', true ) );
                $joyce_ed_post_social_share = esc_html( get_post_meta( $post->ID, 'joyce_ed_post_social_share', true ) );
                $joyce_ed_post_reaction = esc_html( get_post_meta( $post->ID, 'joyce_ed_post_reaction', true ) );
                $joyce_ed_post_rating = esc_html( get_post_meta( $post->ID, 'joyce_ed_post_rating', true ) ); ?>

                <div id="twp-tab-booster-content" class="metabox-content-wrap">

                    <div class="metabox-opt-panel">

                        <h3 class="meta-opt-title"><?php esc_html_e('Booster Extension Plugin Content','joyce'); ?></h3>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="joyce-ed-post-views" name="joyce_ed_post_views" value="1" <?php if( $joyce_ed_post_views ){ echo "checked='checked'";} ?>/>
                            <label for="joyce-ed-post-views"><?php esc_html_e( 'Disable Post Views','joyce' ); ?></label>

                        </div>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="joyce-ed-post-read-time" name="joyce_ed_post_read_time" value="1" <?php if( $joyce_ed_post_read_time ){ echo "checked='checked'";} ?>/>
                            <label for="joyce-ed-post-read-time"><?php esc_html_e( 'Disable Post Read Time','joyce' ); ?></label>

                        </div>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="joyce-ed-post-like-dislike" name="joyce_ed_post_like_dislike" value="1" <?php if( $joyce_ed_post_like_dislike ){ echo "checked='checked'";} ?>/>
                            <label for="joyce-ed-post-like-dislike"><?php esc_html_e( 'Disable Post Like Dislike','joyce' ); ?></label>

                        </div>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="joyce-ed-post-author-box" name="joyce_ed_post_author_box" value="1" <?php if( $joyce_ed_post_author_box ){ echo "checked='checked'";} ?>/>
                            <label for="joyce-ed-post-author-box"><?php esc_html_e( 'Disable Post Author Box','joyce' ); ?></label>

                        </div>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="joyce-ed-post-social-share" name="joyce_ed_post_social_share" value="1" <?php if( $joyce_ed_post_social_share ){ echo "checked='checked'";} ?>/>
                            <label for="joyce-ed-post-social-share"><?php esc_html_e( 'Disable Post Social Share','joyce' ); ?></label>

                        </div>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="joyce-ed-post-reaction" name="joyce_ed_post_reaction" value="1" <?php if( $joyce_ed_post_reaction ){ echo "checked='checked'";} ?>/>
                            <label for="joyce-ed-post-reaction"><?php esc_html_e( 'Disable Post Reaction','joyce' ); ?></label>

                        </div>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="joyce-ed-post-rating" name="joyce_ed_post_rating" value="1" <?php if( $joyce_ed_post_rating ){ echo "checked='checked'";} ?>/>
                            <label for="joyce-ed-post-rating"><?php esc_html_e( 'Disable Post Rating','joyce' ); ?></label>

                        </div>

                    </div>

                </div>
                
            </div>

        </div>  
            
    <?php }
endif;

// Save metabox value.
add_action( 'save_post', 'joyce_save_post_meta' );

if( ! function_exists( 'joyce_save_post_meta' ) ):

    function joyce_save_post_meta( $post_id ) {

        global $post,$joyce_single_image_layout_options;

        if ( !isset( $_POST[ 'joyce_post_meta_nonce' ] ) || !wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['joyce_post_meta_nonce'] ) ), basename( __FILE__ ) ) ){

            return;

        }

        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ){

            return;

        }
            
        if ( 'page' == $_POST['post_type'] ) {  

            if ( !current_user_can( 'edit_page', $post_id ) ){  

                return $post_id;

            }

        }elseif( !current_user_can( 'edit_post', $post_id ) ) {

            return $post_id;

        }

        foreach ( $joyce_single_image_layout_options as $joyce_single_image_layout_option ) {  
            
            $joyce_single_image_layout_old = sanitize_text_field( get_post_meta( $post_id, 'joyce_single_image_layout', true ) ); 
            $joyce_single_image_layout_new = sanitize_text_field( wp_unslash( $_POST['joyce_single_image_layout'] ) );

            if ( $joyce_single_image_layout_new && $joyce_single_image_layout_new != $joyce_single_image_layout_old ){

                update_post_meta ( $post_id, 'joyce_single_image_layout', $joyce_single_image_layout_new );

            }elseif( '' == $joyce_single_image_layout_new && $joyce_single_image_layout_old ) {

                delete_post_meta( $post_id,'joyce_single_image_layout', $joyce_single_image_layout_old );

            }
            
        }


        $twp_disable_ajax_load_next_post_old = sanitize_text_field( get_post_meta( $post_id, 'twp_disable_ajax_load_next_post', true ) ); 
        $twp_disable_ajax_load_next_post_new = isset( $_POST['twp_disable_ajax_load_next_post'] ) ? joyce_sanitize_meta_pagination( wp_unslash( $_POST['twp_disable_ajax_load_next_post'] ) ) : '' ;
        if( $twp_disable_ajax_load_next_post_new && $twp_disable_ajax_load_next_post_new != $twp_disable_ajax_load_next_post_old ){

            update_post_meta ( $post_id, 'twp_disable_ajax_load_next_post', $twp_disable_ajax_load_next_post_new );

        }elseif( '' == $twp_disable_ajax_load_next_post_new && $twp_disable_ajax_load_next_post_old ) {

            delete_post_meta( $post_id,'twp_disable_ajax_load_next_post', $twp_disable_ajax_load_next_post_old );

        }




        $joyce_ed_feature_image_old = absint( get_post_meta( $post_id, 'joyce_ed_feature_image', true ) ); 
        $joyce_ed_feature_image_new = isset( $_POST['joyce_ed_feature_image'] ) ? absint( wp_unslash( $_POST['joyce_ed_feature_image'] ) ) : '';

        if ( $joyce_ed_feature_image_new && $joyce_ed_feature_image_new != $joyce_ed_feature_image_old ){

            update_post_meta ( $post_id, 'joyce_ed_feature_image', $joyce_ed_feature_image_new );

        }elseif( '' == $joyce_ed_feature_image_new && $joyce_ed_feature_image_old ) {

            delete_post_meta( $post_id,'joyce_ed_feature_image', $joyce_ed_feature_image_old );

        }

        $joyce_ed_post_views_old = absint( get_post_meta( $post_id, 'joyce_ed_post_views', true ) ); 
        $joyce_ed_post_views_new = isset( $_POST['joyce_ed_post_views'] ) ? absint( wp_unslash( $_POST['joyce_ed_post_views'] ) ) : '';

        if ( $joyce_ed_post_views_new && $joyce_ed_post_views_new != $joyce_ed_post_views_old ){

            update_post_meta ( $post_id, 'joyce_ed_post_views', $joyce_ed_post_views_new );

        }elseif( '' == $joyce_ed_post_views_new && $joyce_ed_post_views_old ) {

            delete_post_meta( $post_id,'joyce_ed_post_views', $joyce_ed_post_views_old );

        }

        $joyce_ed_post_read_time_old = absint( get_post_meta( $post_id, 'joyce_ed_post_read_time', true ) ); 
        $joyce_ed_post_read_time_new = isset( $_POST['joyce_ed_post_read_time'] ) ? absint( wp_unslash( $_POST['joyce_ed_post_read_time'] ) ) : '';

        if ( $joyce_ed_post_read_time_new && $joyce_ed_post_read_time_new != $joyce_ed_post_read_time_old ){

            update_post_meta ( $post_id, 'joyce_ed_post_read_time', $joyce_ed_post_read_time_new );

        }elseif( '' == $joyce_ed_post_read_time_new && $joyce_ed_post_read_time_old ) {

            delete_post_meta( $post_id,'joyce_ed_post_read_time', $joyce_ed_post_read_time_old );

        }

        $joyce_ed_post_like_dislike_old = absint( get_post_meta( $post_id, 'joyce_ed_post_like_dislike', true ) ); 
        $joyce_ed_post_like_dislike_new = isset( $_POST['joyce_ed_post_like_dislike'] ) ? absint( wp_unslash( $_POST['joyce_ed_post_like_dislike'] ) ) : '';

        if ( $joyce_ed_post_like_dislike_new && $joyce_ed_post_like_dislike_new != $joyce_ed_post_like_dislike_old ){

            update_post_meta ( $post_id, 'joyce_ed_post_like_dislike', $joyce_ed_post_like_dislike_new );

        }elseif( '' == $joyce_ed_post_like_dislike_new && $joyce_ed_post_like_dislike_old ) {

            delete_post_meta( $post_id,'joyce_ed_post_like_dislike', $joyce_ed_post_like_dislike_old );

        }

        $joyce_ed_post_author_box_old = absint( get_post_meta( $post_id, 'joyce_ed_post_author_box', true ) ); 
        $joyce_ed_post_author_box_new = isset( $_POST['joyce_ed_post_author_box'] ) ? absint( wp_unslash( $_POST['joyce_ed_post_author_box'] ) ) : '';

        if ( $joyce_ed_post_author_box_new && $joyce_ed_post_author_box_new != $joyce_ed_post_author_box_old ){

            update_post_meta ( $post_id, 'joyce_ed_post_author_box', $joyce_ed_post_author_box_new );

        }elseif( '' == $joyce_ed_post_author_box_new && $joyce_ed_post_author_box_old ) {

            delete_post_meta( $post_id,'joyce_ed_post_author_box', $joyce_ed_post_author_box_old );

        }

        $joyce_ed_post_social_share_old = absint( get_post_meta( $post_id, 'joyce_ed_post_social_share', true ) ); 
        $joyce_ed_post_social_share_new = isset( $_POST['joyce_ed_post_social_share'] ) ? absint( wp_unslash( $_POST['joyce_ed_post_social_share'] ) ) : '';

        if ( $joyce_ed_post_social_share_new && $joyce_ed_post_social_share_new != $joyce_ed_post_social_share_old ){

            update_post_meta ( $post_id, 'joyce_ed_post_social_share', $joyce_ed_post_social_share_new );

        }elseif( '' == $joyce_ed_post_social_share_new && $joyce_ed_post_social_share_old ) {

            delete_post_meta( $post_id,'joyce_ed_post_social_share', $joyce_ed_post_social_share_old );

        }

        $joyce_ed_post_reaction_old = absint( get_post_meta( $post_id, 'joyce_ed_post_reaction', true ) ); 
        $joyce_ed_post_reaction_new = isset( $_POST['joyce_ed_post_reaction'] ) ? absint( wp_unslash( $_POST['joyce_ed_post_reaction'] ) ) : '';

        if ( $joyce_ed_post_reaction_new && $joyce_ed_post_reaction_new != $joyce_ed_post_reaction_old ){

            update_post_meta ( $post_id, 'joyce_ed_post_reaction', $joyce_ed_post_reaction_new );

        }elseif( '' == $joyce_ed_post_reaction_new && $joyce_ed_post_reaction_old ) {

            delete_post_meta( $post_id,'joyce_ed_post_reaction', $joyce_ed_post_reaction_old );

        }

        $joyce_ed_post_rating_old = absint( get_post_meta( $post_id, 'joyce_ed_post_rating', true ) ); 
        $joyce_ed_post_rating_new = isset( $_POST['joyce_ed_post_rating'] ) ? absint( wp_unslash( $_POST['joyce_ed_post_rating'] ) ) : '';

        if ( $joyce_ed_post_rating_new && $joyce_ed_post_rating_new != $joyce_ed_post_rating_old ){

            update_post_meta ( $post_id, 'joyce_ed_post_rating', $joyce_ed_post_rating_new );

        }elseif( '' == $joyce_ed_post_rating_new && $joyce_ed_post_rating_old ) {

            delete_post_meta( $post_id,'joyce_ed_post_rating', $joyce_ed_post_rating_old );

        }

    }

endif;   